@@ -21,7 +21,12 @@ class EnvOverrideHandler:
                 }
             result = response.json().get("result", {})
             config_id = result.get("environmentConfig", {}).get("id", 0)
-            if not config_id:
+            if config_id == 0:
+                return {
+                    "success": True,
+                    "config_id": 0
+                }
+            elif not config_id:
                 return {
                     "success": False,
                     "error": "Failed to get config id"
@@ -654,17 +659,15 @@ class EnvOverrideHandler:
                         "error": get_config_id["error"]
                     }
                 config_id = get_config_id.get("config_id")
-                if not config_id:
-                    return {
-                        "success": False,
-                        "error": "Failed to handle env_override, Failed to get config_id"
-                    }
-                reset_env_override = EnvOverrideHandler.reset_env_override_template(base_url, headers, app_id, env_id, config_id)
-                if not reset_env_override["success"]:
-                    return {
-                        "success": False,
-                        "error": reset_env_override["error"]
-                    }
+                if config_id == 0:
+                    pass
+                else:
+                    reset_env_override = EnvOverrideHandler.reset_env_override_template(base_url, headers, app_id, env_id, config_id)
+                    if not reset_env_override["success"]:
+                        return {
+                            "success": False,
+                            "error": reset_env_override["error"]
+                        }
                 reset_configmaps = EnvOverrideHandler.reset_config_override(base_url, headers, app_id, env_id, "ConfigMap")
                 if not reset_configmaps["success"]:
                     return {
@@ -697,17 +700,15 @@ class EnvOverrideHandler:
                             "error": get_config_id["error"]
                         }
                     config_id = get_config_id.get("config_id")
-                    if not config_id:
-                        return {
-                            "success": False,
-                            "error": "Failed to handle env_override, Failed to get config_id"
-                        }
-                    reset_env_override = EnvOverrideHandler.reset_env_override_template(base_url, headers, app_id, env_id, config_id)
-                    if not reset_env_override["success"]:
-                        return {
-                            "success": False,
-                            "error": reset_env_override["error"]
-                        }
+                    if config_id == 0:
+                        pass
+                    else:
+                        reset_env_override = EnvOverrideHandler.reset_env_override_template(base_url, headers, app_id, env_id, config_id)
+                        if not reset_env_override["success"]:
+                            return {
+                                "success": False,
+                                "error": reset_env_override["error"]
+                            }
                 else:
 
                     patch_overriden_deployment_template = EnvOverrideHandler.patch_overriden_deployment_template(base_url, headers, app_id, env_id, deployment_template, chart_ref_id, environment_name, namespace)
