@@ -212,6 +212,10 @@ class CdPipelineHandlers:
             cd.pre_deploy_stage = updated_pre_cd_configs
             cd.post_deploy_stage = updated_post_cd_configs
 
+            # Map run_in_app_env flags from config (only supported for pre_cd and post_cd)
+            cd.run_pre_stage_in_env = bool(cd_config.get('pre_cd_configs', {}).get('run_in_app_env', False))
+            cd.run_post_stage_in_env = bool(cd_config.get('post_cd_configs', {}).get('run_in_app_env', False))
+
             patch_cd_result = CdPipelineHandlers.patch_cd_pipeline(base_url, headers, cd, namespace)
 
             if not patch_cd_result["success"]:
@@ -281,8 +285,8 @@ class CdPipelineHandlers:
                     "containerRegistryName": cd_pipeline.container_registry_name,
                     "repoName": cd_pipeline.repo_name,
                     "manifestStorageType": cd_pipeline.manifest_storage_type,
-                    "runPreStageInEnv": False,
-                    "runPostStageInEnv": False,
+                    "runPreStageInEnv": getattr(cd_pipeline, 'run_pre_stage_in_env', False),
+                    "runPostStageInEnv": getattr(cd_pipeline, 'run_post_stage_in_env', False),
                     "preDeployStage": pre_deploy,
                     "postDeployStage": post_deploy,
                     "customTag": cd_pipeline.custom_tag,
