@@ -5,6 +5,28 @@ from deepdiff import DeepDiff
 
 
 class DevtronUtils:
+    def get_app_description_from_metadata(self, app_id):
+        """
+        Fetch app metadata and return the description field from /orchestrator/app/meta/info/{app_id}
+        Args:
+            app_id (int or str): Application ID
+        Returns:
+            str: Description if found, else empty string
+        """
+        try:
+            url = f"{self.base_url}/orchestrator/app/meta/info/{app_id}"
+            response = requests.get(url, headers=self.headers)
+            if response.status_code == 200:
+                data = response.json()
+                result = data.get("result", {})
+                desc = result.get("description")
+                if not desc and "note" in result and isinstance(result["note"], dict):
+                    desc = result["note"].get("description", "")
+                return desc or ""
+            else:
+                return ""
+        except Exception:
+            return ""
     def __init__(self, base_url, headers):
         self.base_url = base_url
         self.headers = headers
@@ -689,4 +711,78 @@ class DevtronUtils:
             return {
                 "success": False,
                 "error": f"Exception occurred: {str(e)}"
-            }
\ No newline at end of file
+            }
+
+  
+    @staticmethod
+    def get_env_id(base_url, headers, environment_name):
+        try:
+            print(f"Getting environment ID for: {environment_name}")
+            response = requests.get(f'{base_url}/orchestrator/env/autocomplete', headers=headers)
+            if response.status_code == 200:
+                environments = response.json().get('result', [])
+                for e in environments:
+                    if e.get("environment_name") == environment_name:
+                        return {
+                            'success': True,
+                            'environment_id': e.get("id"),
+                            'namespace': e.get("namespace")
+                        }
+                return {'success': False, 'error': f'Environment "{environment_name}" not found'}
+            return {'success': False, 'error': f'API request failed: {response.status_code} {response.text}'}
+        except Exception as e:
+            return {'success': False, 'error': f'Exception occurred: {str(e)}'}
+
+# --- YAML utilities for multi-line string handling ---
+
+class CustomDumper(yaml.SafeDumper):
+    """Custom YAML dumper that handles multi-line strings properly."""
+    
+    def choose_scalar_style(self):
+        """
+        Override the style selection to respect our literal presenter.
+        This ensures multi-line strings are output with pipe (|) style.
+        """
+        if self.event.value and '\n' in self.event.value:
+            if self.event.style == '|':
+                return '|'
+        return super().choose_scalar_style()
+
+
+def literal_presenter(dumper, data):
+    """
+    Represent strings with newlines as literal blocks (pipe | style).
+    Single-line strings are represented normally.
+    """
+    if isinstance(data, str) and '\n' in data:
+        return dumper.represent_scalar('tag:yaml.org,2002:str', data, style='|')
+    return dumper.represent_scalar('tag:yaml.org,2002:str', data)
+
+
+# Register the literal presenter with the CustomDumper
+CustomDumper.add_representer(str, literal_presenter)
+
+
+def dump_yaml(data, stream=None, **kwargs):
+    """
+    Dump data to YAML using CustomDumper with sensible defaults.
+    
+    Args:
+        data: The data to serialize to YAML
+        stream: Optional file-like object to write to
+        **kwargs: Additional arguments to pass to yaml.dump()
+    
+    Returns:
+        str if stream is None, otherwise None
+    """
+    defaults = {
+        'Dumper': CustomDumper,
+        'default_flow_style': False,
+        'allow_unicode': True,
+        'sort_keys': False,
+        'width': float("inf")
+    }
+    # Merge provided kwargs with defaults (provided kwargs take precedence)
+    merged_kwargs = {**defaults, **kwargs}
+    
+    return yaml.dump(data, stream=stream, **merged_kwargs)
